package L15_pkg;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.geom.Ellipse2D;
import java.awt.geom.Rectangle2D;

import javax.swing.JPanel;

/**
 * This class encapsulates a JPanel child that has a green ellipse drawn on it.
 * The ellipse is centered and has width and height that is half of this
 * JPanel's width and height. The class does not specify a preferred initial
 * size, so it will resort to the default (128x15 units).
 * 
 * To see how to specify the preferred size for this component rather than
 * resorting to the default, see the example here:
 * http://java.sun.com/products/jfc
 * /tsc/articles/painting/src/SwingPaintDemo.java
 * 
 * @author mb
 * 
 */
public class GreenEllipsePanel extends JPanel {

	/**
	 * Constructor
	 */
	public GreenEllipsePanel() {
		/*
		 * the line below would be invoked by default even it we hadn't
		 * specified it. This corresponds to the constructor JPanel() [see API]
		 */
		super();
	}

	/**
	 * This method implements how this component should be drawn.
	 * 
	 * This method is called when the windowing system determines that the
	 * window to which this component belongs should be re-rendered. The
	 * paint(Graphics g) method is invoked on each of the window's components.
	 * Each of those invocations, in turn, invokes this method,
	 * paintComponent(Graphics g).
	 * 
	 * Swing programs should override paintComponent() instead of overriding
	 * paint() [ref: http://java.sun.com/products/jfc/tsc/articles/painting/]
	 * 
	 */
	public void paintComponent(Graphics g) {
		super.paintComponent(g);

		Graphics2D g2 = (Graphics2D) g;

		g2.setPaint(Color.WHITE);
		g2.fill(new Rectangle2D.Double(0, 0, this.getWidth(), this.getHeight()));

		int ellipseWidth = this.getWidth() / 2;
		int ellipseHeight = this.getHeight() / 2;
		g2.setPaint(Color.GREEN);
		g2.draw(new Ellipse2D.Double((this.getWidth() - ellipseWidth) / 2,
				(this.getHeight() - ellipseHeight) / 2, ellipseWidth,
				ellipseHeight));

	}
}
