package L15_pkg.copy;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.geom.Ellipse2D;
import java.awt.geom.Rectangle2D;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JTable;
import javax.swing.JTextField;

/**
 * <p>
 * The class encapsulates a view of a SimpleThreeDotModel (where a "view" is a
 * visual representation of data). This view is based on a widget container and
 * can be instantiated and displayed.
 * </p>
 * 
 * <p>
 * The view consists of a single widget which provides a single bounded
 * two-dimensional plane. The dots in the data model are each drawn on the plane
 * in their specified location and with their specified size. The user space is
 * mapped directly to the device space.
 * </p>
 * 
 * <p>
 * The only constructor this class has is one that requires a
 * SimpleThreeDotModel object. It doesn't make sense to create this view without
 * its data model.
 * </p>
 * 
 * <p>
 * This view is capable of listening to data models and will install itself on
 * the passed data model. Any time the data model changes, this view will
 * repaint itself.
 * </p>
 * 
 * @author mb
 * 
 */
public class L15Frame extends JFrame {

	/**
	 * Constructs a view as specified in the class description. The view gets
	 * installed upon the passed model.
	 * 
	 * @param model
	 */
	public L15Frame() {
		this.setBackground(Color.RED);

		/*
		 * Here we specify the initial dimension of this frame
		 */
		int width = 400;
		int height = width;
		// this.setSize(width, height);
		// this.setMinimumSize(new Dimension(width, height));
		this.setPreferredSize(new Dimension(width, height));

		/*
		 * This is self-explanatory
		 */
		this.setTitle("My Frame");

		/*
		 * Here we specify the operation that should be performed when this
		 * window is closed (the default is to do nothing)
		 */
		this.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
		/*
		 * Here are some other alternatives:
		 */
		// this.setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
		/*
		 * DO_NOTHING_ON_CLOSE is the default
		 */
		// this.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);

		/*
		 * Here we specify whether this frame is resizable (default is true)
		 */
		this.setResizable(true);

		/*
		 * Here we specify the LayoutManager to use for this frame (default is
		 * BorderLayout)
		 */
		this.setLayout(new BorderLayout());

		/*
		 * here we specify the components that should be added to this top-level
		 * container
		 */
		Container rootContainer = this.getContentPane();

		JPanel thePanel = new GreenEllipsePanel();
		rootContainer.add(thePanel);
		// rootContainer.add(thePanel2, BorderLayout.CENTER);

		// rootContainer.add(new GreenEllipsePanel(), BorderLayout.LINE_START);
		// rootContainer.add(new GreenEllipsePanel(), BorderLayout.LINE_END);

		/*
		 * the method pack() causes this JFrame to be sized to fit the preferred
		 * size and layouts of its subcomponents.
		 */
		this.pack();
		this.setVisible(true);

	}

}
