package L15_pkg.copy;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.geom.Ellipse2D;

import javax.swing.JPanel;
import javax.swing.JTable;
import javax.swing.JTextField;

/**
 * <p>
 * The class encapsulates a view of a SimpleThreeDotModel (where a "view" is a
 * visual representation of data). This view needs to be added to a widget
 * container.
 * </p>
 * 
 * <p>
 * The view consists of a bounded two-dimensional plane. The dots in the data
 * model are each drawn on the plane in their specified location and with their
 * specified size. The user space is mapped directly to the device space.
 * </p>
 * 
 * <p>
 * The only constructor this class has is one that requires a
 * SimpleThreeDotModel object. It doesn't make sense to create this view without
 * its data model.
 * </p>
 * 
 * <p>
 * This view is capable of listening to data models and will install itself on
 * the passed data model. Any time the data model changes, this view will
 * repaint itself.
 * </p>
 * 
 * @author mb
 * 
 */
public class SimplePanel extends JPanel {
	private int width = 400;
	private int height = 400;

	/**
	 * Constructs a view as specified in the class description. The view gets
	 * installed upon the passed model.
	 * 
	 * @param model
	 */
	public SimplePanel() {
	}

	/**
	 * This method renders the graphics of this view.
	 * 
	 * The method is invoked any time the view is repainted. Here is what the
	 * method actually does. We can see that it causes the whole view to be
	 * drawn anew. (Obviously, this is breaking the encapsulation, but is
	 * included for pedagogical reasons). <br />
	 * <code>
	 *  Graphics2D g2 = (Graphics2D) g;<br />
	 *  g2.clearRect(0, 0, width, height);<br />
	 * 	g2.setColor(theModel.getColor1());<br />
	 * 	g2.draw(theModel.getDot1());<br />
	 * 	g2.setColor(theModel.getColour1());<br />
	 * 	g2.draw(theModel.getDot2());<br />
	 * 	g2.setColor(theModel.getColor3());<br />
	 * 	g2.draw(theModel.getDot3());<br />
	 * 
	 * </code>
	 */
	public void paintComponent(Graphics g) {

		// super.paintComponent(g); // yes, this should be the first statement,
		// but I want some parallelism with Version 5
		this.setBackground(Color.YELLOW);

		Graphics2D g2 = (Graphics2D) g;
		g2.clearRect(0, 0, width, height); // this clears the
		// drawing space
		g2.setPaint(Color.GREEN);
		g2.draw(new Ellipse2D.Double(10, 10, 40, 40));
	}

	public Dimension getPreferredSize() {
		return new Dimension(width, height);
	}


}
